@@ -17,20 +17,35 @@ nroKmeans <- function(
     if(length(attr(data, "excl.columns")) > 0)
         warning("Unusable column(s) excluded.")
 
-    # Ensure inputs are safe for C++.
+    # Automatic parameters.
     if(is.null(k)) k <- 3
-    else k <- as.integer(k[[1]])
-    if(is.null(subsample)) subsample <- nrow(data)
-    else subsample <- as.integer(subsample[[1]])
     if(is.null(balance)) balance <- 0.0
-    else balance <- as.double(balance[[1]])
-    if(is.null(message)) message <- -1.0
-    else message <- as.double(message[[1]])
     if(is.null(metric)) metric <- "euclid"
-    else metric <- as.character(metric[[1]])
+    if(is.null(message)) message <- -1.0
+
+    # Automatic subsample.
+    if(is.null(subsample)) {
+        subsample <- 10*sqrt(nrow(data))*sqrt(k)
+	subsample <- min(subsample, 0.95*nrow(data), na.rm=TRUE)
+        if(subsample/nrow(data) < balance)
+            subsample <- balance*nrow(data)
+	subsample <- round(subsample)
+    }
+
+    # Ensure inputs are safe for C++.
+    k <- as.integer(k[[1]])
+    subsample <- as.integer(subsample[[1]])
+    balance <- as.double(balance[[1]])
+    metric <- as.character(metric[[1]])
+    message <- as.double(message[[1]])
+
+    # Check balance parameter.
+    if(!is.finite(balance)) stop("Unusable balance parameter.")
+    if(balance < 0.0) stop("Unusable balance parameter.")
+    if(balance > 1.0) stop("Unusable balance parameter.")
 
     # Check subsample size.
-    if(!is.finite(subsample)) subsample <- nrow(data)
+    if(!is.finite(subsample)) stop("Unusable subsample.")
     if(subsample > nrow(data)) subsample <- nrow(data)
     if(subsample < (k + 10)) stop("Too small subsample.")
 
@@ -41,53 +56,6 @@ nroKmeans <- function(
     # Check message interval.
     if(!is.finite(message)) message <- -1.0
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-    # Ensure parameter inputs are safe for C++.
-    k <- as.integer(k[[1]])
-    if(is.null(subsample)) subsample <- nrow(data)
-    else subsample <- as.integer(subsample[[1]])
-    balance <- as.double(balance[[1]])
-    metric <- as.character(metric[[1]])
-
-    # Check the number of centroids.
-    if(!is.finite(k)) stop("Unusable number of centroids.")
-    if(k >= 0.5*nrow(data)) stop("Less than two rows per centroid.")
-    if(k < 2) stop("Less than two centroids.")
-    
-    # Check subsample size.
-    if(!is.finite(subsample)) stop("Unusable subsample size.")
-    if(k > subsample/2)
-       stop("Less than two subsampled rows per centroid.")
-    if(subsample > nrow(data)) subsample <- nrow(data)
-
-    # Check balance parameter.
-    if(!is.finite(balance)) stop("Unusable balancing parameter.")
-    if(balance < 0.0) stop("Negative balancing parameter.")
-    if(balance > 1.0) stop("Unusable balancing parameter.")
-
-    # Check distance metric.
-    if((metric != "euclid") && (metric != "pearson"))
-        stop("Unknown distance metric.")
- 
-    # Check message interval.
-    if(is.null(message)) message <- -1.0
-    message <- as.double(message[[1]])
-    if(!is.finite(message)) message <- -1.0
-
     # Estimate centroids.
     res <- .Call("nro_train",
                  as.matrix(k),
@@ -108,5 +76,6 @@ nroKmeans <- function(
 
     # Copy column names.
     colnames(res$centroids) <- colnames(data)
+    res$subsample <- subsample
     return(res)
 }
